// ColorPane.java
// A simple extension of JTextPane that allows the user to easily append
// colored text to the document.
//

package ParaIrc.client;
import javax.swing.*;
import javax.swing.text.*;

import java.awt.Color;
import java.awt.Font;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.TimeZone;

public class ParaIrcGuiColorPane extends JTextPane {

	private JScrollBar scrollBar;
	
	public ParaIrcGuiColorPane(){
		super();
		this.setEditable(false);
		this.setFont(new Font(ParaIrc.getConfig("chatFont"), Font.LAYOUT_LEFT_TO_RIGHT, ParaIrc.getConfigInt("chatFontsize")));
	}
	
	public ParaIrcGuiColorPane(JScrollPane textScrollPane) {
		super();
		this.setEditable(false);
		scrollBar=textScrollPane.getHorizontalScrollBar();
		this.setFont(new Font(ParaIrc.getConfig("chatFont"), Font.LAYOUT_LEFT_TO_RIGHT, ParaIrc.getConfigInt("chatFontsize")));
		
			
	}


public void append(Color c, String message, boolean bold)
{
    this.append(c,message,bold,false,true);
}
	
public void append(Color c, String message, boolean bold, boolean underline, boolean displaytime) 
{
    
    
    StyleContext sc = StyleContext.getDefaultStyleContext();
    AttributeSet aset = sc.addAttribute(SimpleAttributeSet.EMPTY,
                                        StyleConstants.Foreground, c);


    // char 0x1F is underlined
    // char 0x02 is bold
    if (message.indexOf("\u0002")>=0)
    {
        append(c,message.substring(0,message.indexOf("\u0002")),bold,underline,displaytime);
        append(c,message.substring(message.indexOf("\u0002")+1),!bold,underline,false);
        return;
    }
    
    if (message.indexOf("\u001F")>=0)
    {
        append(c,message.substring(0,message.indexOf("\u001F")),bold,underline,displaytime);
        append(c,message.substring(message.indexOf("\u001F")+1),bold,!underline,false);
        return;
    }
        
    setCharacterAttributes(aset, false);
    
    SimpleAttributeSet attrib  = new SimpleAttributeSet();
    StyleConstants.setBold(attrib, bold);
    StyleConstants.setUnderline(attrib, underline);
	attrib.addAttributes(aset);
	
    String time=ParaIrc.getConfig("time");
	
    if(!displaytime)
    {
        time="";
    }
	
    if (time!="")
    {
		SimpleDateFormat fmt = new SimpleDateFormat();
		fmt.applyPattern(time);
		Calendar cal = new GregorianCalendar(TimeZone.getTimeZone("ECT"));
		time=fmt.format(cal.getTime())+" ";
    	
    }

    
	try 
	{
		this.getDocument().insertString(getDocument().getLength(),time+message,attrib);
	} 
	catch (BadLocationException e) 
	{
		e.printStackTrace();
	}
	
	setCaretPosition(getDocument().getLength());
	
	/*if(scrollBar.getMaximum()-30<scrollBar.getValue()+scrollBar.getVisibleAmount())
	{
	    scrollBar.setValue(scrollBar.getMaximum()-scrollBar.getVisibleAmount());
	    setCaretPosition(getDocument().getLength());
	}*/
	

	
  }


public void setScrollBar(JScrollPane textScrollPane) {
	scrollBar=textScrollPane.getVerticalScrollBar();
	scrollBar.setValue(scrollBar.getMaximum());	
}

/**
 * @param Color
 * @param Message
 */
public void append(Color c, String string) {
    append(c,string,false);
    
}

  
}