
package ParaIrc.client;

import java.awt.Color;

import ParaIrc.irclib.Irc;
import ParaIrc.irclib.IrcInterface;

// loads and handles IRCLib
public class ParaIrcLoader implements IrcInterface {

	Irc ircLib;
	ParaIrcGui gui;
	
	public Irc getIrcLib()
	{
		return ircLib;
	}
	
	public ParaIrcLoader(ParaIrcGui gui)
	{
		this.gui=gui;
		gui.setLoader(this);
		ircLib = new Irc(this);
		Thread loaderThread = new Thread(ircLib);
		refreshIrcLib();
		loaderThread.start();
	}


	/**
	 * refresh Options for IrcLib
	 */
	public void refreshIrcLib() {
		ircLib.setCheckMessageInterval(ParaIrc.getConfigInt("checkMessageInterval"));
		ircLib.setNick(ParaIrc.getConfig("nickname"));
		ircLib.setRealName(ParaIrc.getConfig("Realname"));
		ircLib.setServer(ParaIrc.getConfig("Server"));
		ircLib.setPort(ParaIrc.getConfigInt("port"));
		ircLib.setAutoConnect(ParaIrc.getConfigInt("autoconnect"));
		ircLib.setServerTimeout(ParaIrc.getConfigInt("ServerTimeout"));
		ircLib.setcheckConn(ParaIrc.getConfigInt("PingServer"));
		
	}

	public void ircReady() {
		// TODO Auto-generated method stub
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#ircConnected()
	 */
	public void ircConnected() {
		gui.updateName("connecting to "+ircLib.getServerString());
		
	}

	/* (non-Javadoc) 
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#serverWelcome()
	 */
	public void serverWelcome() {
		performOnWelcome();	
		gui.getChannels().rejoinAll();
		gui.updateName(ircLib.getNick()+"@"+ircLib.getServerString());
		
	}

	/**
	 * perform commands on Server Welcome
	 */
	private void performOnWelcome() {
		String perform= ParaIrc.getConfig("Perform");
		String tempPerform="";
		if (!perform.equals(""))
		{
			while(perform.indexOf("@")>-1)
			{
				tempPerform=perform.substring(0,perform.indexOf("@"));
				if (tempPerform.indexOf("/")==0)
				{
					ircLib.getIrc().processMessage(tempPerform,"");
				}
				perform=perform.substring(perform.indexOf("@")+1,perform.length());
			}
			if (perform.indexOf("/")==0)
			{
				ircLib.getIrc().processMessage(perform,"");
			}
		}		
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#nickProblems()
	 */
	public void nickProblems(String message) {
		// TODO Auto-generated method stub
		ParaIrc.getGui().getStatusField().printMessage(message);	
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#serverMessage(int, java.lang.String)
	 */
	public void serverMessage(String code, String message) {
		// TODO Auto-generated method stub
		ParaIrc.getGui().getStatusField().printMessage(code+"-"+message);	
		
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#userMessage(java.lang.String, java.lang.String)
	 */
	public void userMessage(String user, String message) {
		gui.getChannels().messageFromUser(user,message);
		
		
		//ParaIrc.getGui().getStatusField().printMessage(message);	
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#channelMessage(java.lang.String, java.lang.String)
	 */
	public void channelMessage(String channel,String sender, String message) {
	    if (sender.trim().equalsIgnoreCase(getIrcLib().getNick().trim())) // Sender is current User
		{
		    gui.getChannels().sendToChannel(channel,"<"+sender+"> "+message,ParaIrc.getColor("myText"));
		}
		else
		{ 
		    if (message.toLowerCase().indexOf(getIrcLib().getNick().toLowerCase())>=0)
		    {	// My Nick is in the Message
		        gui.getChannels().sendToChannel(channel,"<"+sender+"> "+message,Color.BLACK,true);
		    }
		    else
		    {
		        gui.getChannels().sendToChannel(channel,"<"+sender+"> "+message,Color.BLACK);
		    }
		}
		
	}
	
	public void channelMessage(String channel,String message) {
			gui.getChannels().sendToChannel(channel,message,Color.BLACK);
			
		}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#handleException(java.lang.Exception)
	 */
	public void handleException(Exception e) {
		e.printStackTrace();
		
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#returnMessage(java.lang.String)
	 */
	public void returnMessage(String message) {
		// TODO Auto-generated method stub
		ParaIrc.getGui().getStatusField().printMessage(message);
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#getVersion()
	 */
	public String getVersion(String user) {
		if (user!="")
		{
			ParaIrc.getGui().getStatusField().printMessage("[VERSION] Request by "+user ,ParaIrc.getColor("Versionrequest"));
		} 
		return ParaIrc.AppTitle+" running on "+System.getProperty("os.name")+" "+System.getProperty("os.version");
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#getQuitMessage()
	 */
	public String getQuitMessage() {
		// TODO Auto-generated method stub
		return ParaIrc.getConfig("QuitMessage");
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#userPart(java.lang.String, java.lang.String)
	 */
	public void userPart(String channel, String user) {
		gui.getChannels().getChannel(channel).removeUser(user);
		gui.getChannels().sendToChannel(channel,user+" has left",ParaIrc.getColor("part"));
		
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#userJoin(java.lang.String, java.lang.String)
	 */
	public void userJoin(String user,String channel) {
		if (!user.equalsIgnoreCase(ircLib.getNick()))
		{
			gui.getChannels().sendToChannel(channel,user+" has joined",ParaIrc.getColor("join"));
			gui.getChannels().getChannel(channel).addUser(user);
		}
		else
		{
			gui.getChannels().sendToChannel(channel,"You have joined "+channel,ParaIrc.getColor("join"));
		}
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#userQuit(java.lang.String, java.lang.String)
	 */
	public void userQuit(String user, String message) {
		gui.getChannels().userQuit(user,message);
		
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#userNickChange(java.lang.String, java.lang.String)
	 */
	public void userNickChange(String oldNick, String newNick) {
		gui.updateName(ircLib.getNick()+"@"+ircLib.getServerString());
		gui.getChannels().userChangedNick(oldNick,newNick);
		
	}

	/**
	 * @param string
	 */
	protected void processMessage(String message,String channel) {
		// TODO Auto-generated method stub
		ircLib.processMessage(message,channel);
	}

	/* (non-Javadoc)
	 * Add User from /NAMES Command
	 */
	public void addUsers(String channel, String text) 
	{
		ParaIrcChannels channels=gui.getChannels();
		while(text.indexOf(" ")>-1)
			{
				String user = text.substring(0,text.indexOf(" "));
				text=text.substring(text.indexOf(" ")+1);
				channels.getChannel(channel).addUser(user);
			}	
		
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#setChannelInfo(java.lang.String, java.lang.String)
	 */
	public void setChannelInfo(String channel, String text) {
		// TODO Auto-generated method stub
		gui.getChannels().getChannel(channel).setTopicInfo(text);
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#setTopic(java.lang.String, java.lang.String)
	 */
	public void setTopic(String channel, String text) {
		// TODO Auto-generated method stub
		gui.getChannels().getChannel(channel).setTopic(text);
		
	}

	public void changeNickMode(char c, char mode, String nick,String channel,String setUser) {
		gui.getChannels().sendToChannel(channel,setUser+" has set mode : "+c+mode+" "+nick,ParaIrc.getColor("setmode"));
		gui.getChannels().getChannel(channel).getUserList().changeNickMode(c,mode,nick);
		
	}

	public void returnCTCP(String text) {
		ParaIrc.getGui().getStatusField().printMessage(text,ParaIrc.getColor("CTCPReply"));
		
	}

	public void disconnected() {
		gui.getChannels().leaveAllChannels();
		gui.getStatusField().printMessage("Disconnected from Server");
		gui.updateName("not connected");
		
	}

	public void userKicked(String channel, String user,String kickedUser,String reason) {
		if (kickedUser.equals(ircLib.getNick()))
		{
			gui.getChannels().getChannel(channel).leave();
			gui.getStatusField().printMessage(channel+": You have been kicked by "+user+" ("+reason+")",ParaIrc.getColor("kicked"));
		}
		else
		{
			gui.getChannels().getChannel(channel).removeUser(kickedUser); 
			gui.getChannels().sendToChannel(channel,kickedUser+" has been kicked by "+user+" ("+reason+")",ParaIrc.getColor("kicked"));
		}	
	}

	
	public void askDCCRequest(int i, String sender, String command, String filename) {
		ircLib.acceptDCCQueue(i);		
	}

	/* (non-Javadoc)
	 * @see Paranoid.ParaIrc.irclib.IrcInterface#changeTopic(java.lang.String, java.lang.String)
	 */
	public void changeTopic(String sender,String channel, String topic) {
		gui.getChannels().sendToChannel(channel,sender+ " changed Topic to "+topic,ParaIrc.getColor("setmode"));
		gui.getChannels().getChannel(channel).setTopic(topic);
	}
}
